pub enum Node {
Part(Part),
File(FilePart),
Multipart((HeaderMap, Vec<Node>)),
}Expand description
A multipart part which could be either a file, in memory, or another multipart container containing nested parts.
Variants
Part(Part)
A part in memory
File(FilePart)
A part streamed to a file
Multipart((HeaderMap, Vec<Node>))
A container of nested multipart parts