pub struct FilePart {
pub headers: HeaderMap,
pub path: PathBuf,
pub size: Option<usize>,
tempdir: Option<PathBuf>,
}Expand description
A file that is to be inserted into a multipart/* or alternatively an uploaded file that
was received as part of multipart/* parsing.
Fields
headers: HeaderMapThe headers of the part
path: PathBufA temporary file containing the file content
size: Option<usize>Optionally, the size of the file. This is filled when multiparts are parsed, but is not necessary when they are generated.
tempdir: Option<PathBuf>Implementations